@@ -32,7 +32,7 @@ Kwave::MultiTrackReader::MultiTrackReader()
 //***************************************************************************
 Kwave::MultiTrackReader::MultiTrackReader(Kwave::ReaderMode mode,
                                           Kwave::SignalManager &signal_manager,
-                                          const QList<unsigned int> &track_list,
+					  const QVector<unsigned int> &track_list,
                                           sample_index_t first,
                                           sample_index_t last)
     :Kwave::MultiTrackSource<Kwave::SampleReader, false>(0),
